import { CssNode } from './private.js';
import Stylesheet from './Stylesheet.js';
import Element from '../nodes/Element.js';
import magic_string from 'magic-string';
import Component from '../Component.js';
export default class Selector {
    /**
     * @param  node
     * @param  stylesheet
     */
    constructor(node: CssNode, stylesheet: Stylesheet);
    /** @type {CssNode} */
    node: CssNode;
    /** @type {Stylesheet} */
    stylesheet: Stylesheet;
    /** @type {Block[]} */
    blocks: Block[];
    /** @type {Block[]} */
    local_blocks: Block[];
    /** @type {boolean} */
    used: boolean;
    /** @param {Element} node */
    apply(node: Element): void;
    /** @param {magic_string} code */
    minify(code: magic_string): void;
    /**
     * @param  code
     * @param  attr
     * @param  max_amount_class_specificity_increased
     */
    transform(code: magic_string, attr: string, max_amount_class_specificity_increased: number): void;
    /** @param {Component} component */
    validate(component: Component): void;
    /** @param {Component} component */
    validate_global_with_multiple_selectors(component: Component): void;
    /** @param {Component} component */
    validate_invalid_combinator_without_selector(component: Component): void;
    /** @param {Component} component */
    validate_global_compound_selector(component: Component): void;
    get_amount_class_specificity_increased(): number;
}
export type NodeExistsValue = (typeof NodeExist)[keyof typeof NodeExist];
declare class Block {
    /** @param {CssNode} combinator */
    constructor(combinator: CssNode);
    /** @type {boolean} */
    host: boolean;
    /** @type {boolean} */
    root: boolean;
    /** @type {CssNode} */
    combinator: CssNode;
    /** @type {CssNode[]} */
    selectors: CssNode[];
    /** @type {number} */
    start: number;
    /** @type {number} */
    end: number;
    /** @type {boolean} */
    should_encapsulate: boolean;
    /** @param {CssNode} selector */
    add(selector: CssNode): void;
    get global(): boolean;
}
declare namespace NodeExist {
    const Probably: 0;
    const Definitely: 1;
}
export {};
