import { Ast, CssHashGetter } from '../../interfaces.js';
import { CssNode } from './private.js';
import Element from '../nodes/Element.js';
import magic_string, { SourceMap } from 'magic-string';
import Component from '../Component.js';
import Selector from './Selector.js';
export default class Stylesheet {
    /**
 * @param  params
     */
    constructor({ source, ast, component_name, filename, dev, get_css_hash }: {
        source: string;
        ast: Ast;
        filename: string | undefined;
        component_name: string | undefined;
        dev: boolean;
        get_css_hash: CssHashGetter;
    });
    /** @type {string} */
    source: string;
    /** @type {Ast} */
    ast: Ast;
    /** @type {string} */
    filename: string;
    /** @type {boolean} */
    dev: boolean;
    /** @type {boolean} */
    has_styles: boolean;
    /** @type {string} */
    id: string;
    /** @type {Array<Rule | Atrule>} */
    children: Array<Rule | Atrule>;
    /** @type {Map<string, string>} */
    keyframes: Map<string, string>;
    /** @type {Set<CssNode>} */
    nodes_with_css_class: Set<CssNode>;
    /** @param {Element} node */
    apply(node: Element): void;
    reify(): void;
    /** @param {string} file */
    render(file: string): {
        code: string;
        map: SourceMap;
    };
    /** @param {Component} component */
    validate(component: Component): void;
    /** @param {Component} component */
    warn_on_unused_selectors(component: Component): void;
}
declare class Rule {
    /**
     * @param  node
     * @param  stylesheet
     * @param  [parent]
     */
    constructor(node: CssNode, stylesheet: any, parent?: Atrule);
    /** @type {Selector[]} */
    selectors: Selector[];
    /** @type {Declaration[]} */
    declarations: Declaration[];
    /** @type {CssNode} */
    node: CssNode;
    /** @type {Atrule} */
    parent: Atrule;
    /** @param {Element} node */
    apply(node: Element): void;
    /** @param {boolean} dev */
    is_used(dev: boolean): boolean;
    /**
     * @param  code
     * @param  _dev
     */
    minify(code: magic_string, _dev: boolean): void;
    /**
     * @param  code
     * @param  id
     * @param  keyframes
     * @param  max_amount_class_specificity_increased
     */
    transform(code: magic_string, id: string, keyframes: Map<string, string>, max_amount_class_specificity_increased: number): boolean;
    /** @param {Component} component */
    validate(component: Component): void;
    /** @param {(selector: Selector) => void} handler */
    warn_on_unused_selector(handler: (selector: Selector) => void): void;
    get_max_amount_class_specificity_increased(): number;
}
declare class Atrule {
    /** @param {CssNode} node */
    constructor(node: CssNode);
    /** @type {CssNode} */
    node: CssNode;
    /** @type {Array<Atrule | Rule>} */
    children: Array<Atrule | Rule>;
    /** @type {Declaration[]} */
    declarations: Declaration[];
    /** @param {Element} node */
    apply(node: Element): void;
    /** @param {boolean} _dev */
    is_used(_dev: boolean): boolean;
    /**
     * @param  code
     * @param  dev
     */
    minify(code: magic_string, dev: boolean): void;
    /**
     * @param  code
     * @param  id
     * @param  keyframes
     * @param  max_amount_class_specificity_increased
     */
    transform(code: magic_string, id: string, keyframes: Map<string, string>, max_amount_class_specificity_increased: number): void;
    /** @param {Component} component */
    validate(component: Component): void;
    /** @param {(selector: Selector) => void} handler */
    warn_on_unused_selector(handler: (selector: Selector) => void): void;
    get_max_amount_class_specificity_increased(): any;
}
declare class Declaration {
    /** @param {CssNode} node */
    constructor(node: CssNode);
    /** @type {CssNode} */
    node: CssNode;
    /**
     * @param  code
     * @param  keyframes
     */
    transform(code: magic_string, keyframes: Map<string, string>): void;
    /** @param {magic_string} code */
    minify(code: magic_string): void;
}
export {};
