import { INode } from './interfaces.js';
import Component from '../Component.js';
import Node from './shared/Node.js';
import TemplateScope from './shared/TemplateScope.js';
import Action from './Action.js';
import Binding from './Binding.js';
import Class from './Class.js';
import StyleDirective from './StyleDirective.js';
import EventHandler from './EventHandler.js';
import Let from './Let.js';
import Transition from './Transition.js';
import Animation from './Animation.js';
import Expression from './shared/Expression.js';
/** @extends Node<'Element'> */
export default class Element extends Node<"Element", INode> {
    /**
     * @param  component
     * @param  parent
     * @param  scope
     * @param  info  undefined
     */
    constructor(component: Component, parent: Node<any, INode>, scope: TemplateScope, info: any);
    /** @type {string} */
    name: string;
    /** @type {TemplateScope} */
    scope: TemplateScope;
    /** @type {Action[]} */
    actions: Action[];
    /** @type {Binding[]} */
    bindings: Binding[];
    /** @type {Class[]} */
    classes: Class[];
    /** @type {StyleDirective[]} */
    styles: StyleDirective[];
    /** @type {EventHandler[]} */
    handlers: EventHandler[];
    /** @type {Let[]} */
    lets: Let[];
    /** @type {Transition} */
    intro: Transition;
    /** @type {Transition} */
    outro: Transition;
    /** @type {Animation} */
    animation: Animation;
    /** @type {INode[]} */
    children: INode[];
    /** @type {string} */
    namespace: string;
    /** @type {boolean} */
    needs_manual_style_scoping: boolean;
    /** @type {Expression} */
    tag_expr: Expression;
    /** @type {boolean} */
    contains_a11y_label: boolean;
    get is_dynamic_element(): boolean;
    validate(): void;
    validate_attributes(): void;
    validate_attributes_a11y(): void;
    validate_special_cases(): void;
    validate_bindings_foreign(): void;
    validate_bindings(): void;
    validate_content(): void;
    validate_event_handlers(): void;
    is_media_node(): boolean;
    add_css_class(): void;
    get slot_template_name(): string;
    optimise(): void;
    get can_use_textcontent(): boolean;
    get can_optimise_to_html_string(): boolean;
    hash(): string;
}
import Node from './shared/Node.js';
