import { Identifier, Node } from 'estree';
import Renderer, { BindingGroup } from './Renderer.js';
import Wrapper from './wrappers/shared/Wrapper.js';
export default class Block {
    /** @param {BlockOptions} options */
    constructor(options: {
        parent?: Block;
        name: Identifier;
        type: string;
        renderer?: Renderer;
        comment?: string;
        key?: Identifier;
        bindings?: Map<string, {
            object: Identifier;
            property: Identifier;
            snippet: Node;
            store: string;
            modifier: (node: Node) => Node;
        }>;
        dependencies?: Set<string>;
    });
    /**
     * @typedef {Object} Bindings
     * @property {Identifier} object
     * @property {Identifier} property
     * @property {Node} snippet
     * @property {string} store
     * @property {(node:Node) => Node} modifier
     */
    /**
     * @typedef {Object} BlockOptions
     * @property {Block} [parent]
     * @property {Identifier} name
     * @property {string} type
     * @property {Renderer} [renderer]
     * @property {string} [comment]
     * @property {Identifier} [key]
     * @property {Map<string,Bindings>} [bindings]
     * @property {Set<string>} [dependencies]
     */
    /** @type {Block} */
    parent: Block;
    /** @type {Renderer} */
    renderer: Renderer;
    /** @type {Identifier} */
    name: Identifier;
    /** @type {string} */
    type: string;
    /** @type {string} */
    comment: string;
    /** @type {Wrapper[]} */
    wrappers: Wrapper[];
    /** @type {Identifier} */
    key: Identifier;
    /** @type {Identifier} */
    first: Identifier;
    /** @type {Set<string>} */
    dependencies: Set<string>;
    /** @type {Map<string, Bindings>} */
    bindings: Map<string, {
        object: Identifier;
        property: Identifier;
        snippet: Node;
        store: string;
        modifier: (node: Node) => Node;
    }>;
    /** @type {Set<string>} */
    binding_group_initialised: Set<string>;
    /** @type {Set<BindingGroup>} */
    binding_groups: Set<BindingGroup>;
    /**
     * @type {{
     * 		declarations: Array<Node | Node[]>;
     * 		init: Array<Node | Node[]>;
     * 		create: Array<Node | Node[]>;
     * 		claim: Array<Node | Node[]>;
     * 		hydrate: Array<Node | Node[]>;
     * 		mount: Array<Node | Node[]>;
     * 		measure: Array<Node | Node[]>;
     * 		restore_measurements: Array<Node | Node[]>;
     * 		fix: Array<Node | Node[]>;
     * 		animate: Array<Node | Node[]>;
     * 		intro: Array<Node | Node[]>;
     * 		update: Array<Node | Node[]>;
     * 		outro: Array<Node | Node[]>;
     * 		destroy: Array<Node | Node[]>;
     * 	}}
     */
    chunks: {
        declarations: Array<Node | Node[]>;
        init: Array<Node | Node[]>;
        create: Array<Node | Node[]>;
        claim: Array<Node | Node[]>;
        hydrate: Array<Node | Node[]>;
        mount: Array<Node | Node[]>;
        measure: Array<Node | Node[]>;
        restore_measurements: Array<Node | Node[]>;
        fix: Array<Node | Node[]>;
        animate: Array<Node | Node[]>;
        intro: Array<Node | Node[]>;
        update: Array<Node | Node[]>;
        outro: Array<Node | Node[]>;
        destroy: Array<Node | Node[]>;
    };
    /** @type {Node[]} */
    event_listeners: Node[];
    /** @type {boolean} */
    maintain_context: boolean;
    /** @type {boolean} */
    has_animation: boolean;
    /** @type {boolean} */
    has_intros: boolean;
    /** @type {boolean} */
    has_outros: boolean;
    /** @type {boolean} */
    has_intro_method: boolean;
    /** @type {boolean} */
    has_outro_method: boolean;
    /** @type {number} */
    outros: number;
    /** @type {Map<string, Identifier>} */
    aliases: Map<string, Identifier>;
    /** @type {Map<string, { id: Identifier; init?: Node }>} */
    variables: Map<string, {
        id: Identifier;
        init?: Node;
    }>;
    /** @type {(name: string) => Identifier} */
    get_unique_name: (name: string) => Identifier;
    /** */
    has_update_method: boolean;
    /** @type {{ element_var: string; condition_expression?: any }} */
    autofocus: {
        element_var: string;
        condition_expression?: any;
    };
    assign_variable_names(): void;
    /** @param {Set<string>} dependencies */
    add_dependencies(dependencies: Set<string>): void;
    /**
     * @param  id
     * @param  render_statement
     * @param  claim_statement
     * @param  parent_node
     * @param  [no_detach]
     */
    add_element(id: Identifier, render_statement: Node, claim_statement: Node, parent_node: Node, no_detach?: boolean): void;
    /** @param {boolean} [local] */
    add_intro(local?: boolean): void;
    /** @param {boolean} [local] */
    add_outro(local?: boolean): void;
    add_animation(): void;
    /**
     * @param  id
     * @param  [init]
     */
    add_variable(id: Identifier, init?: Node): void;
    /** @param {string} name */
    alias(name: string): Identifier;
    /** @param {BlockOptions} options */
    child(options: {
        parent?: Block;
        name: Identifier;
        type: string;
        renderer?: Renderer;
        comment?: string;
        key?: Identifier;
        bindings?: Map<string, {
            object: Identifier;
            property: Identifier;
            snippet: Node;
            store: string;
            modifier: (node: Node) => Node;
        }>;
        dependencies?: Set<string>;
    }): Block;
    /** @param {any} [key] */
    get_contents(key?: any): Node[];
    /** @returns {boolean} */
    has_content(): boolean;
    render(): Node[];
    /** @param {string} chunk */
    render_listeners(chunk?: string): void;
    render_binding_groups(): void;
}
