import Component from '../Component.js';
import { CompileOptions, Var } from '../../interfaces.js';
import { Literal, Node, Identifier, Expression, UnaryExpression, ArrayExpression, MemberExpression, PrivateIdentifier } from 'estree';
import Block from './Block.js';
import Fragment from './wrappers/Fragment.js';
export default class Renderer {
    /**
     * @param  component
     * @param  options
     */
    constructor(component: Component, options: CompileOptions);
    /**
     * @typedef {Object} ContextMember
     * @property {string} name
     * @property {Literal} index
     * @property {boolean} is_contextual
     * @property {boolean} is_non_contextual
     * @property {Var} variable
     * @property {number} priority
     */
    /**
     * @typedef {Array<{
     * 	n: number;
     * 	names: string[];
     * }>} BitMasks
     */
    /** @type {Component} */
    component: Component;
    /** @type {CompileOptions} */
    options: CompileOptions;
    /** @type {ContextMember[]} */
    context: {
        name: string;
        index: Literal;
        is_contextual: boolean;
        is_non_contextual: boolean;
        variable: Var;
        priority: number;
    }[];
    /** @type {ContextMember[]} */
    initial_context: {
        name: string;
        index: Literal;
        is_contextual: boolean;
        is_non_contextual: boolean;
        variable: Var;
        priority: number;
    }[];
    /** @type {Map<string, ContextMember>} */
    context_lookup: Map<string, {
        name: string;
        index: Literal;
        is_contextual: boolean;
        is_non_contextual: boolean;
        variable: Var;
        priority: number;
    }>;
    /** @type {boolean} */
    context_overflow: boolean;
    /** @type {Array<Block | Node | Node[]>} */
    blocks: Array<Block | Node | Node[]>;
    /** @type {Set<string>} */
    readonly: Set<string>;
    /** @type {Array<Node | Node[]>} */
    meta_bindings: Array<Node | Node[]>;
    /** @type {Map<string, BindingGroup>} */
    binding_groups: Map<string, BindingGroup>;
    /** @type {Block} */
    block: Block;
    /** @type {Fragment} */
    fragment: Fragment;
    /** @type {Identifier} */
    file_var: Identifier;
    /** @type {(c: number) => { line: number; column: number }} */
    locate: (c: number) => {
        line: number;
        column: number;
    };
    /**
     * @param  name
     * @param  contextual
     */
    add_to_context(name: string, contextual?: any): {
        name: string;
        index: Literal;
        is_contextual: boolean;
        is_non_contextual: boolean;
        variable: Var;
        priority: number;
    };
    /**
     * @param  name
     * @param  [value]
     * @param  main_execution_context
     */
    invalidate(name: string, value?: unknown, main_execution_context?: boolean): Node;
    /**
     * @param  names
     * @param  is_reactive_declaration
     * @returns 
     */
    dirty(names: string[], is_reactive_declaration?: any): Expression;
    /** @returns {UnaryExpression | ArrayExpression} */
    get_initial_dirty(): UnaryExpression | ArrayExpression;
    /**
     * @param  node
     * @param  ctx
     */
    reference(node: string | Identifier | MemberExpression, ctx?: string | void): any;
    /** @param {Block | Node | Node[]} block */
    remove_block(block: Block | Node | Node[]): void;
}
export type BindingGroup = {
    binding_group: (to_reference?: boolean) => Node;
    contexts: string[];
    list_dependencies: Set<string>;
    keypath: string;
    add_element: (block: Block, element: PrivateIdentifier) => void;
    render: (block: Block) => void;
};
import Block from './Block.js';
