import ElseBlock from '../../nodes/ElseBlock.js';
import Renderer from '../Renderer.js';
import Block from '../Block.js';
import Wrapper from './shared/Wrapper.js';
import Fragment from './Fragment.js';
import EachBlock from '../../nodes/EachBlock.js';
import { Identifier, Node } from 'estree';
/** @extends Wrapper<ElseBlock> */
export class ElseBlockWrapper extends Wrapper<ElseBlock> {
    /**
     * @param  renderer
     * @param  block
     * @param  parent
     * @param  node
     * @param  strip_whitespace
     * @param  next_sibling
     */
    constructor(renderer: Renderer, block: Block, parent: Wrapper, node: ElseBlock, strip_whitespace: boolean, next_sibling: Wrapper);
    /** @type {Block} */
    block: Block;
    /** @type {Fragment} */
    fragment: Fragment;
    /** @type {boolean} */
    is_dynamic: boolean;
    var: any;
}
/** @extends Wrapper<EachBlock> */
export default class EachBlockWrapper extends Wrapper<EachBlock> {
    /**
     * @param  renderer
     * @param  block
     * @param  parent
     * @param  node
     * @param  strip_whitespace
     * @param  next_sibling
     */
    constructor(renderer: Renderer, block: Block, parent: Wrapper, node: EachBlock, strip_whitespace: boolean, next_sibling: Wrapper);
    /** @type {Block} */
    block: Block;
    /** @type {Fragment} */
    fragment: Fragment;
    /** @type {ElseBlockWrapper} */
    else: ElseBlockWrapper;
    /**
     * @type {{
     * 		create_each_block: Identifier;
     * 		each_block_value: Identifier;
     * 		get_each_context: Identifier;
     * 		iterations: Identifier;
     * 		fixed_length: number;
     * 		data_length: Node | number;
     * 		view_length: Node | number;
     * 	}}
     */
    vars: {
        create_each_block: Identifier;
        each_block_value: Identifier;
        get_each_context: Identifier;
        iterations: Identifier;
        fixed_length: number;
        data_length: Node | number;
        view_length: Node | number;
    };
    /** @type {Array<Node | Node[]>} */
    context_props: Array<Node | Node[]>;
    /** @type {Identifier} */
    index_name: Identifier;
    /** @type {Array<Node | Node[]>} */
    updates: Array<Node | Node[]>;
    /** @type {Set<string>} */
    dependencies: Set<string>;
    /**
     * @param  block
     * @param  parent_node
     * @param  parent_nodes
     */
    render(block: Block, parent_node: Identifier, parent_nodes: Identifier): void;
    /**
 * @param  params
     */
    render_keyed({ block, parent_node, parent_nodes, snippet, initial_anchor_node, initial_mount_node, update_anchor_node, update_mount_node }: {
        block: Block;
        parent_node: Identifier;
        parent_nodes: Identifier;
        snippet: Node;
        initial_anchor_node: Identifier;
        initial_mount_node: Identifier;
        update_anchor_node: Identifier;
        update_mount_node: Identifier;
    }): void;
    /**
 * @param  params
     */
    render_unkeyed({ block, parent_nodes, snippet, initial_anchor_node, initial_mount_node, update_anchor_node, update_mount_node }: {
        block: Block;
        parent_nodes: Identifier;
        snippet: Node;
        initial_anchor_node: Identifier;
        initial_mount_node: Identifier;
        update_anchor_node: Identifier;
        update_mount_node: Identifier;
    }): void;
}
import Wrapper from './shared/Wrapper.js';
