import Element from '../../../nodes/Element.js';
import Renderer from '../../Renderer.js';
import Block from '../../Block.js';
import Wrapper from '../shared/Wrapper.js';
import Fragment from '../Fragment.js';
import StyleAttribute from './StyleAttribute.js';
import SpreadAttribute from './SpreadAttribute.js';
import Binding from './Binding.js';
import EventHandler from './EventHandler.js';
import { Identifier, Expression } from 'estree';
/** @extends Wrapper<Element> */
export default class ElementWrapper extends Wrapper<Element> {
    /**
     * @param  renderer
     * @param  block
     * @param  parent
     * @param  node
     * @param  strip_whitespace
     * @param  next_sibling
     */
    constructor(renderer: Renderer, block: Block, parent: Wrapper, node: Element, strip_whitespace: boolean, next_sibling: Wrapper);
    /** @type {Fragment} */
    fragment: Fragment;
    /** @type {Array<AttributeWrapper | StyleAttribute | SpreadAttribute>} */
    attributes: Array<AttributeWrapper | StyleAttribute | SpreadAttribute>;
    /** @type {Binding[]} */
    bindings: Binding[];
    /** @type {EventHandler[]} */
    event_handlers: EventHandler[];
    /** @type {string[]} */
    class_dependencies: string[];
    /** @type {Set<string>} */
    dynamic_style_dependencies: Set<string>;
    /** @type {boolean} */
    has_dynamic_attribute: boolean;
    /** @type {Set<string>} */
    select_binding_dependencies: Set<string>;
    /** @type {boolean} */
    has_dynamic_value: boolean;
    /** @type {any} */
    dynamic_value_condition: any;
    /** @type {any} */
    var: any;
    /** @type {boolean} */
    void: boolean;
    /** @type {Block} */
    child_dynamic_element_block: Block;
    /** @type {ElementWrapper} */
    child_dynamic_element: ElementWrapper;
    /** */
    element_data_name: any;
    /**
     * @param  block
     * @param  parent_node
     * @param  parent_nodes
     */
    render(block: Block, parent_node: Identifier, parent_nodes: Identifier): void;
    /**
     * @param  block
     * @param  parent_node
     * @param  parent_nodes
     */
    render_dynamic_element(block: Block, parent_node: Identifier, parent_nodes: Identifier): void;
    /**
     * @param  block
     * @param  parent_node
     * @param  parent_nodes
     */
    render_element(block: Block, parent_node: Identifier, parent_nodes: Identifier): void;
    /** @param {Block} block */
    get_render_statement(block: Block): Expression & {
        start: number;
        end: number;
    };
    /**
     * @param  block
     * @param  nodes
     * @param  to_optimise_hydration
     */
    get_claim_statement(block: Block, nodes: Identifier, to_optimise_hydration: boolean): Expression & {
        start: number;
        end: number;
    };
    /** @param {Block} block */
    add_directives_in_order(block: Block): void;
    /**
     * @param  block
     * @param  binding_group
     */
    add_bindings(block: Block, binding_group: BindingGroup): void;
    /**
     * @param  block
     * @param  this_binding
     */
    add_this_binding(block: Block, this_binding: Binding): void;
    /** @param {Block} block */
    add_attributes(block: Block): void;
    /** @param {Block} block */
    add_spread_attributes(block: Block): void;
    /** @param {Block} block */
    add_dynamic_element_attributes(block: Block): void;
    /** @param {Block} block */
    add_transitions(block: Block): void;
    /** @param {Block} block */
    add_animation(block: Block): void;
    /** @param {Block} block */
    add_classes(block: Block): void;
    /** @param {Block} block */
    add_styles(block: Block): void;
    /** @param {Block} block */
    add_manual_style_scoping(block: Block): void;
}
export type BindingGroup = {
    events: string[];
    bindings: Binding[];
};
import Wrapper from '../shared/Wrapper.js';
import AttributeWrapper from './Attribute.js';
