import { ParserOptions, Ast, TemplateNode, Fragment, Style, Script } from '../interfaces.js';
/**
 * @param  template
 * @param  options
 * @returns 
 */
export default function parse(template: string, options?: ParserOptions): Ast;
export class Parser {
    /**
     * @param  template
     * @param  options
     */
    constructor(template: string, options: ParserOptions);
    /**
     * @readonly
     * @type {string}
     */
    readonly template: string;
    /**
     * @readonly
     * @type {string}
     */
    readonly filename: string;
    /**
     * @readonly
     * @type {boolean}
     */
    readonly customElement: boolean;
    /**
     * @readonly
     * @type {'injected' | 'external' | 'none' | boolean}
     */
    readonly css_mode: 'injected' | 'external' | 'none' | boolean;
    index: number;
    /**
     * @type {TemplateNode[]}
     */
    stack: TemplateNode[];
    /**
     * @type {Fragment}
     */
    html: Fragment;
    /**
     * @type {Style[]}
     */
    css: Style[];
    /**
     * @type {Script[]}
     */
    js: Script[];
    meta_tags: {};
    /**
     * @type {{tag: string; reason: string; depth: number;}}
     */
    last_auto_closed_tag: {
        tag: string;
        reason: string;
        depth: number;
    };
    current(): TemplateNode;
    /**
     * @param  err
     */
    acorn_error(err: any): void;
    /**
     * @param  err
     */
    error({ code, message }: {
        code: string;
        message: string;
    }, index?: number): void;
    /**
     * @param  str
     * @param  [required]
     * @param  [error]
     */
    eat(str: string, required?: boolean, error?: {
        code: string;
        message: string;
    }): boolean;
    /**
     * @param  str
     */
    match(str: string): boolean;
    /**
     * Match a regex at the current index
     * @param  pattern  Should have a ^ anchor at the start so the regex doesn't search past the beginning, resulting in worse performance
     */
    match_regex(pattern: RegExp): string;
    allow_whitespace(): void;
    /**
     * Search for a regex starting at the current index and return the result if it matches
     * @param  pattern  Should have a ^ anchor at the start so the regex doesn't search past the beginning, resulting in worse performance
     */
    read(pattern: RegExp): string;
    read_identifier(allow_reserved?: boolean): string;
    /**
     * @param  pattern
     * @param  [error_message]
     */
    read_until(pattern: RegExp, error_message?: [{
        code: string;
        message: string;
    }, number?][0]): string;
    require_whitespace(): void;
}
