import { DecodedSourceMap, RawSourceMap } from '@ampproject/remapping';
import source_map from '@ampproject/remapping/dist/types/source-map.js';
import { SourceMap } from 'magic-string';
import { Processed } from '../preprocess/public.js';
import { Source } from '../preprocess/private.js';
/**
 * @param  map
 * @param  offset
 * @param  source_index
 */
export function sourcemap_add_offset(map: DecodedSourceMap, offset: {
    line: number;
    column: number;
}, source_index: number): void;
/**
 * @param  filename
 * @param  sourcemap_list
 */
export function combine_sourcemaps(filename: string, sourcemap_list: Array<DecodedSourceMap | RawSourceMap>): source_map;
/**
 * @param  filename
 * @param  svelte_map
 * @param  preprocessor_map_input
 * @returns 
 */
export function apply_preprocessor_sourcemap(filename: string, svelte_map: SourceMap, preprocessor_map_input: string | DecodedSourceMap | RawSourceMap): SourceMap;
/**
 * @param  processed
 * @param  tag_name
 * @returns 
 */
export function parse_attached_sourcemap(processed: Processed, tag_name: 'script' | 'style'): void;
/** */
export class MappedCode {
    /**
     * @static
     * @param  string
     * @param  [map]
     * @returns 
     */
    static from_processed(string: string, map?: DecodedSourceMap): MappedCode;
    /**
     * @static
     * @param  opts
     * @returns 
     */
    static from_source({ source, file_basename, get_location }: Source): MappedCode;
    constructor(string?: string, map?: any);
    /**
     * @type {string}
     */
    string: string;
    /**
     * @type {DecodedSourceMap}
     */
    map: DecodedSourceMap;
    /**
     * concat in-place (mutable), return this (chainable)
     * will also mutate the `other` object
     * @param  other
     * @returns 
     */
    concat(other: MappedCode): MappedCode;
}
