import { ComponentConstructorOptions } from './public.js';
/**
 * @param  type
 * @param  detail
 * @returns 
 */
export function dispatch_dev<T>(type: string, detail: T): void;
/**
 * @param  target
 * @param  node
 * @returns 
 */
export function append_dev(target: Node, node: Node): void;
/**
 * @param  target
 * @param  node
 * @returns 
 */
export function append_hydration_dev(target: Node, node: Node): void;
/**
 * @param  target
 * @param  node
 * @param  anchor
 * @returns 
 */
export function insert_dev(target: Node, node: Node, anchor: Node): void;
/** @param {Node} target
 * @param  node
 * @param  anchor
 * @returns 
 */
export function insert_hydration_dev(target: Node, node: Node, anchor: Node): void;
/**
 * @param  node
 * @returns 
 */
export function detach_dev(node: Node): void;
/**
 * @param  before
 * @param  after
 * @returns 
 */
export function detach_between_dev(before: Node, after: Node): void;
/**
 * @param  after
 * @returns 
 */
export function detach_before_dev(after: Node): void;
/**
 * @param  before
 * @returns 
 */
export function detach_after_dev(before: Node): void;
/**
 * @param  node
 * @param  event
 * @param  handler
 * @param  options
 * @param  has_prevent_default
 * @param  has_stop_propagation
 * @param  has_stop_immediate_propagation
 * @returns 
 */
export function listen_dev(node: Node, event: string, handler: EventListenerOrEventListenerObject, options: boolean | AddEventListenerOptions | EventListenerOptions, has_prevent_default: boolean, has_stop_propagation: boolean, has_stop_immediate_propagation: boolean): () => void;
/**
 * @param  node
 * @param  attribute
 * @param  value
 * @returns 
 */
export function attr_dev(node: Element, attribute: string, value: string): void;
/**
 * @param  node
 * @param  property
 * @param  value
 * @returns 
 */
export function prop_dev(node: Element, property: string, value: any): void;
/**
 * @param  node
 * @param  property
 * @param  value
 * @returns 
 */
export function dataset_dev(node: HTMLElement, property: string, value: any): void;
/**
 * @param  text
 * @param  data
 * @returns 
 */
export function set_data_dev(text: Text, data: unknown): void;
/**
 * @param  text
 * @param  data
 * @returns 
 */
export function set_data_contenteditable_dev(text: Text, data: unknown): void;
/**
 * @param  text
 * @param  data
 * @param  attr_value
 * @returns 
 */
export function set_data_maybe_contenteditable_dev(text: Text, data: unknown, attr_value: string): void;
export function ensure_array_like_dev(arg: any): any;
/**
 * @returns  */
export function validate_slots(name: any, slot: any, keys: any): void;
/**
 * @param  tag
 * @returns 
 */
export function validate_dynamic_element(tag: unknown): void;
/**
 * @param  tag
 * @returns 
 */
export function validate_void_dynamic_element(tag: undefined | string): void;
export function construct_svelte_component_dev(component: any, props: any): any;
/** @returns {() => void} */
export function loop_guard(timeout: any): () => void;
/**
 * Base class for Svelte components with some minor dev-enhancements. Used when dev=true.
 *
 * Can be used to create strongly typed Svelte components.
 *
 * ### Example:
 *
 * You have component library on npm called `component-library`, from which
 * you export a component called `MyComponent`. For Svelte+TypeScript users,
 * you want to provide typings. Therefore you create a `index.d.ts`:
 * ```ts
 * import { SvelteComponent } from "svelte";
 * export class MyComponent extends SvelteComponent<{foo: string}> {}
 * ```
 * Typing this makes it possible for IDEs like VS Code with the Svelte extension
 * to provide intellisense and to use the component like this in a Svelte file
 * with TypeScript:
 * ```svelte
 * <script lang="ts">
 * 	import { MyComponent } from "component-library";
 * </script>
 * <MyComponent foo={'bar'} />
 * ```
 * @extends SvelteComponent<Props, Events>
 */
export class SvelteComponentDev<Props extends Record<string, any> = any, Events extends Record<string, any> = any, Slots extends Record<string, any> = any> extends SvelteComponent<Props, Events> {
    /** @param {ComponentConstructorOptions<Props>} options */
    constructor(options: ComponentConstructorOptions<Props>);
    /**
     * For type checking capabilities only.
     * Does not exist at runtime.
     * ### DO NOT USE!
     *
     * @type {Props}
     */
    $$prop_def: Props;
    /**
     * For type checking capabilities only.
     * Does not exist at runtime.
     * ### DO NOT USE!
     *
     * @type {Events}
     */
    $$events_def: Events;
    /**
     * For type checking capabilities only.
     * Does not exist at runtime.
     * ### DO NOT USE!
     *
     * @type {Slots}
     */
    $$slot_def: Slots;
    /** @returns {void} */
    $capture_state(): void;
    /** @returns {void} */
    $inject_state(): void;
}
/**
 * @deprecated Use `SvelteComponent` instead. See PR for more information: https://github.com/sveltejs/svelte/pull/8512
 * @extends SvelteComponentDev<Props, Events, Slots>
 */
export class SvelteComponentTyped<Props extends Record<string, any> = any, Events extends Record<string, any> = any, Slots extends Record<string, any> = any> extends SvelteComponentDev<Props, Events, Slots> {
}
import { SvelteComponent } from './Component.js';
